==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Недостаје лозинка кључа за опоравак",
    "Please repeat the recovery key password" : "Поновите лозинку кључа за опоравак",
    "Repeated recovery key password does not match the provided recovery key password" : "Поновљена лозинка кључа за опоравак се не поклапа",
    "Recovery key successfully enabled" : "Кључ за опоравак успешно укључен",
    "Could not enable recovery key. Please check your recovery key password!" : "Не могу да укључим кључ за опоравак. Проверите лозинку кључа за опоравак!",
    "Recovery key successfully disabled" : "Кључ за опоравак успешно искључен",
    "Could not disable recovery key. Please check your recovery key password!" : "Не могу да искључим кључ за опоравак. Проверите лозинку!",
    "Missing parameters" : "Недостају параметри",
    "Please provide the old recovery password" : "Унесите стару лозинку опоравка",
    "Please provide a new recovery password" : "Унесите нову лозинку опоравка",
    "Please repeat the new recovery password" : "Поновите нову лозинку опоравка",
    "Password successfully changed." : "Лозинка успешно промењена.",
    "Could not change the password. Maybe the old password was not correct." : "Не могу да променим лозинку. Можда стара лозинка није исправна.",
    "Recovery Key disabled" : "Кључ за опоравак искључен",
    "Recovery Key enabled" : "Кључ за опоравак укључен",
    "Could not enable the recovery key, please try again or contact your administrator" : "Не могу да укључим кључ за опоравак. Покушајте поново или контактирајте администратора",
    "Could not update the private key password." : "Не могу да ажирирам лозинку личног кључа.",
    "The old password was not correct, please try again." : "Стара лозинка није исправна. Покушајте поново.",
    "The current log-in password was not correct, please try again." : "Тренутна лозинка за пријаву није исправна. Покушајте поново.",
    "Private key password successfully updated." : "Лозинка личног кључа је успешно ажурирана.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Морате да пребаците старе шифрарске кључеве (оунКлауд <= 8.0) у нови. Укључите „оунКлауд подразумевани шифрарски модул“ и покрените 'occ encryption:migrate'",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не могу да дешифрујем фајл. Вероватно је то дељен фајл. Затражите од власника фајла да га поново подели са вама.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не могу да читам фајл. Вероватно је дељен. Питајте власника да га поново подели са вама.",
    "The share will expire on %s." : "Дељење истиче %s.",
    "Cheers!" : "Здраво!",
    "Enable recovery key" : "Омогући кључ за опоравак",
    "Disable recovery key" : "Онемогући кључ за опоравак",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Кључ за опоравак је додатни шифрарски кључ који се користи за шифровање фајлова. Он омогућава опоравак корисничких фајлова ако корисник заборави своју лозинку.",
    "Recovery key password" : "Лозинка кључа за опоравак",
    "Repeat recovery key password" : "Поновите лозинку кључа за опоравак",
    "Change recovery key password:" : "Измена лозинке кључа опоравка:",
    "Old recovery key password" : "Стара лозинка кључа за опоравак",
    "New recovery key password" : "Нова лозинка кључа за опоравак",
    "Repeat new recovery key password" : "Поновите нову лозинку кључа за опоравак",
    "Change Password" : "Измени лозинку",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Апликација шифровања је укључена али ваши кључеви нису иницијализовани. Одјавите се и поново се пријавите.",
    "Your private key password no longer matches your log-in password." : "Лозинка вашег личног кључа више није иста као ваша лозинка за пријаву.",
    "Set your old private key password to your current log-in password:" : "Поставите стару лозинку личног кључа као тренутну лозинку за пријаву:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ако се не сећате старе лозинке, можете затражити од администратора да опорави ваше фајлове.",
    "Old log-in password" : "Стара лозинка за пријаву",
    "Current log-in password" : "Тренутна лозинка за пријаву",
    "Update Private Key Password" : "Ажурирај лозинку личног кључа",
    "Enable password recovery:" : "Укључи опоравак лозинке:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Укључивање ове опције омогућиће поновно добијање приступа вашим шифрованим фајловима у случају губитка лозинке",
    "Enabled" : "укључено",
    "Disabled" : "искључено"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/sr.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Недостаје лозинка кључа за опоравак",
    "Please repeat the recovery key password" : "Поновите лозинку кључа за опоравак",
    "Repeated recovery key password does not match the provided recovery key password" : "Поновљена лозинка кључа за опоравак се не поклапа",
    "Recovery key successfully enabled" : "Кључ за опоравак успешно укључен",
    "Could not enable recovery key. Please check your recovery key password!" : "Не могу да укључим кључ за опоравак. Проверите лозинку кључа за опоравак!",
    "Recovery key successfully disabled" : "Кључ за опоравак успешно искључен",
    "Could not disable recovery key. Please check your recovery key password!" : "Не могу да искључим кључ за опоравак. Проверите лозинку!",
    "Missing parameters" : "Недостају параметри",
    "Please provide the old recovery password" : "Унесите стару лозинку опоравка",
    "Please provide a new recovery password" : "Унесите нову лозинку опоравка",
    "Please repeat the new recovery password" : "Поновите нову лозинку опоравка",
    "Password successfully changed." : "Лозинка успешно промењена.",
    "Could not change the password. Maybe the old password was not correct." : "Не могу да променим лозинку. Можда стара лозинка није исправна.",
    "Recovery Key disabled" : "Кључ за опоравак искључен",
    "Recovery Key enabled" : "Кључ за опоравак укључен",
    "Could not enable the recovery key, please try again or contact your administrator" : "Не могу да укључим кључ за опоравак. Покушајте поново или контактирајте администратора",
    "Could not update the private key password." : "Не могу да ажирирам лозинку личног кључа.",
    "The old password was not correct, please try again." : "Стара лозинка није исправна. Покушајте поново.",
    "The current log-in password was not correct, please try again." : "Тренутна лозинка за пријаву није исправна. Покушајте поново.",
    "Private key password successfully updated." : "Лозинка личног кључа је успешно ажурирана.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Морате да пребаците старе шифрарске кључеве (оунКлауд <= 8.0) у нови. Укључите „оунКлауд подразумевани шифрарски модул“ и покрените 'occ encryption:migrate'",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не могу да дешифрујем фајл. Вероватно је то дељен фајл. Затражите од власника фајла да га поново подели са вама.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не могу да читам фајл. Вероватно је дељен. Питајте власника да га поново подели са вама.",
    "The share will expire on %s." : "Дељење истиче %s.",
    "Cheers!" : "Здраво!",
    "Enable recovery key" : "Омогући кључ за опоравак",
    "Disable recovery key" : "Онемогући кључ за опоравак",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Кључ за опоравак је додатни шифрарски кључ који се користи за шифровање фајлова. Он омогућава опоравак корисничких фајлова ако корисник заборави своју лозинку.",
    "Recovery key password" : "Лозинка кључа за опоравак",
    "Repeat recovery key password" : "Поновите лозинку кључа за опоравак",
    "Change recovery key password:" : "Измена лозинке кључа опоравка:",
    "Old recovery key password" : "Стара лозинка кључа за опоравак",
    "New recovery key password" : "Нова лозинка кључа за опоравак",
    "Repeat new recovery key password" : "Поновите нову лозинку кључа за опоравак",
    "Change Password" : "Измени лозинку",
    "Your private key password no longer matches your log-in password." : "Лозинка вашег личног кључа више није иста као ваша лозинка за пријаву.",
    "Set your old private key password to your current log-in password:" : "Поставите стару лозинку личног кључа као тренутну лозинку за пријаву:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Ако се не сећате старе лозинке, можете затражити од администратора да опорави ваше фајлове.",
    "Old log-in password" : "Стара лозинка за пријаву",
    "Current log-in password" : "Тренутна лозинка за пријаву",
    "Update Private Key Password" : "Ажурирај лозинку личног кључа",
    "Enable password recovery:" : "Укључи опоравак лозинке:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Укључивање ове опције омогућиће поновно добијање приступа вашим шифрованим фајловима у случају губитка лозинке",
    "Enabled" : "укључено",
    "Disabled" : "искључено",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Апликација шифровања је укључена али ваши кључеви нису иницијализовани. Одјавите се и поново се пријавите."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
